==> hoteldruid-mod-sv_2.1.2-1.tar.gz: sv/inizio.php <==
<?php

switch ($messaggio) {

case "Menù principale dell'anno":             	$messaggio = "Huvudmenyn f&ouml;r &aring;r"; break;
case "Inserisci una nuova prenotazione":      	$messaggio = "L&auml;gg till en ny reservation"; break;
case "Gennaio":                               	$messaggio = "januari"; break;
case "Febbraio":                              	$messaggio = "februari"; break;
case "Marzo":                                 	$messaggio = "mars"; break;
case "Aprile":      				$messaggio = "april"; break;
case "Maggio":                           	$messaggio = "maj"; break;
case "Giugno":                            	$messaggio = "juni"; break;
case "Luglio":                            	$messaggio = "juli"; break;
case "Agosto":  				$messaggio = "augusti"; break;
case "Settembre":  				$messaggio = "september"; break;
case "Ottobre":  				$messaggio = "oktober"; break;
case "Novembre":  				$messaggio = "november"; break;
case "Dicembre":  				$messaggio = "december"; break;
case "tutte le prenotazioni":  			$messaggio = "alla reservationer"; break;
case "le spese e le entrate":  			$messaggio = "kvitton och betalningar"; break;
case "i periodi e le tariffe":  		$messaggio = "perioder och prislistor"; break;
case "tutti i clienti":  			$messaggio = "alla kunder"; break;
case "le regole di assegnazione":  		$messaggio = "&ouml;verl&aring;telseregler"; break;
case "Inserisci un nuovo cliente":		$messaggio = "L&auml;gg till kund"; break;
case "Spese ed entrate":  			$messaggio = "Cash receipts and payments"; break;
case "al":  					$messaggio = "till"; break;
case "per":  					$messaggio = "f&ouml;r"; break;
case "persone":	  				$messaggio = "personer"; break;
case "Inserisci o modifica i prezzi":  		$messaggio = "L&auml;gg till eller redigera priser"; break;
case "Inserisci o modifica le regole di assegnazione":  $messaggio = "L&auml;gg till eller redigera &ouml;verl&aring;tningsreglerna"; break;
case "Configura e personalizza":	$messaggio = "Konfigurera och anpassa"; break;
case "richiedi l'anno":  			$messaggio = "G&aring; till &aring;r"; break;
case "vai":  					$messaggio = "g&aring;"; break;
case "Non esiste l'anno ":  			$messaggio = "&Aring;r "; break;
case " nel database":  				$messaggio = " finns inte i databasen"; break;
case "Crea l'anno":  				$messaggio = "Skapa &aring;r"; break;
case "Domenica":  				$messaggio = "s&ouml;ndag"; break;
case "Lunedì":  				$messaggio = "m&aring;ndag"; break;
case "Martedì":  				$messaggio = "tisdag"; break;
case "Mercoledì":  				$messaggio = "onsdag"; break;
case "Giovedì":  				$messaggio = "torsdag"; break;
case "Venerdì":  				$messaggio = "fredag"; break;
case "Sabato":	 		 		$messaggio = "l&ouml;rdag"; break;
case "come giorno di inizio/fine locazione":	$messaggio = "som begynnelse-/slutdag f&ouml;r hyran"; break;
case "con periodi":  				$messaggio = "med perioder enligt"; break;
case "settimanali":  				$messaggio = "veckovis"; break;
case "giornalieri":  				$messaggio = "dagligen"; break;
case "e prenotazioni da":  			$messaggio = "och reservationer fr&aring;n"; break;
case "a":  					$messaggio = "till"; break;
case "anno successivo": 			$messaggio = "n&auml;sta &aring;r"; break;
case "anni successivi":  			$messaggio = "&aring;r senare"; break;
case "Importa dall'anno precedente prenotazioni, tariffe (compresi costi aggiuntivi), privilegi degli utenti e regole d'assegnazione.":  $messaggio = "Importera fr&aring;n tidigare &aring;rs reservationer, prislistor (inklusive extrakostnader), anv&auml;ndarprivilegier och &ouml;verl&aring;telseregler."; break;
case "Anno ":  					$messaggio = "&Aring;r "; break;
case " creato":  				$messaggio = " skapad"; break;
case "Non ci sono periodi che riguardano il ":  $messaggio = "Det finns inga perioder f&ouml;r "; break;
case " nel ":  					$messaggio = " "; break;
case ", o il giorno di inizio/fine locazione era differente, sono stati importati solo i dati riguardanti costi aggiuntivi, caparra, nome delle tariffe, privilegi degli utenti e regole di assegnazione 2 e 3":	$messaggio = ", eller begynnelse-/slutdatumet f&ouml;r hyran var annorlunda, endast information om till&auml;gskostnader, depositioner, namn p&aring; prislistor, anv&auml;ndarprivilegier och &ouml;verl&aring;telsereglerna 2 och 3 har importerats"; break;
case "Attenzione</b></font>: i periodi del ":  	$messaggio = "Varning</b></font>: perioderna "; break;
case " finivano dopo quelli del ":  		$messaggio = " slutar efter  "; break;
case " e vi erano":  				$messaggio = " och det finns"; break;
case "prenotazioni che finivano dopo il limite posto al ":	$messaggio = "reservationer som slutar efter gr&auml;nserna som givits f&ouml;r  "; break;
case ", queste prenotazioni non sono state importate":	$messaggio = ", dessa reservationer har inte importerats"; break;
case "Anno già creato": 			$messaggio = "&Aring;ret har redan skapats"; break;
case " Do":  					$messaggio = " S&ouml;"; break;
case " Lu":  					$messaggio = " M&aring;"; break;
case " Ma":  					$messaggio = " Ti"; break;
case " Me":  					$messaggio = " On"; break;
case " Gi":  					$messaggio = " To"; break;
case " Ve":  					$messaggio = " Fr"; break;
case " Sa":  					$messaggio = " L&ouml;"; break;
case "Gen":  					$messaggio = "jan"; break;
case "Feb":  					$messaggio = "feb"; break;
case "Mar":  					$messaggio = "mar"; break;
case "Apr":  					$messaggio = "apr"; break;
case "Mag":  					$messaggio = "maj"; break;
case "Giu":  					$messaggio = "jun"; break;
case "Lug":  					$messaggio = "jul"; break;
case "Ago":  					$messaggio = "aug"; break;
case "Set":  					$messaggio = "sep"; break;
case "Ott":  					$messaggio = "okt"; break;
case "Nov":  					$messaggio = "nov"; break;
case "Dic":  					$messaggio = "dec"; break;
case "Il formato dell'anno richiesto è sbagliato":	$messaggio = "Formatet f&ouml;r det &ouml;nskade &aring;ret &auml;r fel"; break;
case "I mesi erano indicati erroneamente, sono stati inseriti i mesi da Gennaio a Dicembre":	$messaggio = "M&aring;naderna har valts felaktigt, de ska l&auml;ggas in fr&aring;n januari till december"; break;
case "Cognome del cliente":  			$messaggio = "Kund efternamn"; break;
case "Data iniziale":  				$messaggio = "Startdatum"; break;
case "Data finale":  				$messaggio = "Slutdatum"; break;
case "Tariffa completa":  			$messaggio = "Komplett pris"; break;
case "Da pagare":  				$messaggio = "Att betala"; break;
case "Pers":  					$messaggio = "Pers"; break;
case "Registra":  				$messaggio = "Registrera"; break;
case "Entrata":  				$messaggio = "Incheckad"; break;
case "Uscita":  				$messaggio = "Utcheckad"; break;
case "Entrata e pagato":  			$messaggio = "Incheckad och betalad"; break;
case "Uscita e pagato":  			$messaggio = "Utcheckad och betalad"; break;
case "mostra tutte le date":  			$messaggio = "visa alla datum"; break;
case "Utente":  				$messaggio = "Anv&auml;ndare"; break;
case "Esci":  					$messaggio = "Logga ut"; break;
case "Messaggi":  				$messaggio = "Meddelanden"; break;
case "dalla":  					$messaggio = "fr&aring;n"; break;
case "tabella con i periodi e le tariffe":  	$messaggio = "tabellen med perioder och priser"; break;
case "Non ho i permessi di scrittura sulla cartella dati":	$messaggio = "Jag har inte skrivr&auml;ttigheter till dati-mappen"; break;
case "le statistiche":  			$messaggio = "statistiken"; break;
case "inventario e magazzini":  		$messaggio = "inventarier och f&ouml;rvaringsrum"; break;
case "prenotazioni del mese di": 		$messaggio = "reservations in"; break;
case "visualizza": 				$messaggio = "view"; break;
case "tabella con":  				$messaggio = "table with"; break;
case "disponibilità dal":  			$messaggio = "availability from"; break;
case "controlla":  				$messaggio = "check"; break;
case "N&deg;":  				$messaggio = "N&deg;"; break;
case "<span class=\"colred\">Avviso</span>: è consigliabile attendere fino al":	$messaggio = "<span class=\"colred\">Warning</span>: you are advised to wait until"; break;
case "per creare il nuovo anno, nel frattempo si possono aggiungere periodi oltre il":	$messaggio = "before creating the new year, meanwhile you can add periods beyond"; break;
case "anche senza creare un nuovo anno":  	$messaggio = "even without creating a new year"; break;
case "obsoleti":  				$messaggio = "obsolete"; break;
case "Ultimo aggiornamento":  			$messaggio = "Last update"; break;
case "Aggiorna":  				$messaggio = "Update"; break;
case "i documenti salvati":  			$messaggio = "saved documents"; break;
case "Punto vendita":  				$messaggio = "Point of sale"; break;
case "Non ho i permessi per creare nuove tabelle nel database":	$messaggio = "I don't have permissions to create new tables in the database"; break;
case "Benvenuto a HOTELDRUID":  		$messaggio = "Welcome to HOTELDRUID"; break;
case "Scegli la lingua":  			$messaggio = "Choose the language"; break;
case "crea il database":  			$messaggio = "create database"; break;
case "Promemoria":  				$messaggio = "Reminder"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-sv_2.2.3-1.tar.gz: sv/inizio.php <==
<?php

switch ($messaggio) {

case "Menù principale dell'anno":             	$messaggio = "Huvudmenyn f&ouml;r &aring;r"; break;
case "Inserisci una nuova prenotazione":      	$messaggio = "L&auml;gg till en ny reservation"; break;
case "Gennaio":                               	$messaggio = "januari"; break;
case "Febbraio":                              	$messaggio = "februari"; break;
case "Marzo":                                 	$messaggio = "mars"; break;
case "Aprile":      				$messaggio = "april"; break;
case "Maggio":                           	$messaggio = "maj"; break;
case "Giugno":                            	$messaggio = "juni"; break;
case "Luglio":                            	$messaggio = "juli"; break;
case "Agosto":  				$messaggio = "augusti"; break;
case "Settembre":  				$messaggio = "september"; break;
case "Ottobre":  				$messaggio = "oktober"; break;
case "Novembre":  				$messaggio = "november"; break;
case "Dicembre":  				$messaggio = "december"; break;
case "tutte le prenotazioni":  			$messaggio = "alla reservationer"; break;
case "le spese e le entrate":  			$messaggio = "kvitton och betalningar"; break;
case "i periodi e le tariffe":  		$messaggio = "perioder och prislistor"; break;
case "tutti i clienti":  			$messaggio = "alla kunder"; break;
case "le regole di assegnazione":  		$messaggio = "&ouml;verl&aring;telseregler"; break;
case "Inserisci un nuovo cliente":		$messaggio = "L&auml;gg till kund"; break;
case "Spese ed entrate":  			$messaggio = "Cash receipts and payments"; break;
case "al":  					$messaggio = "till"; break;
case "per":  					$messaggio = "f&ouml;r"; break;
case "persone":	  				$messaggio = "personer"; break;
case "Inserisci o modifica i prezzi":  		$messaggio = "L&auml;gg till eller redigera priser"; break;
case "Inserisci o modifica le regole di assegnazione":  $messaggio = "L&auml;gg till eller redigera &ouml;verl&aring;tningsreglerna"; break;
case "Configura e personalizza":	$messaggio = "Konfigurera och anpassa"; break;
case "richiedi l'anno":  			$messaggio = "G&aring; till &aring;r"; break;
case "vai":  					$messaggio = "g&aring;"; break;
case "Non esiste l'anno ":  			$messaggio = "&Aring;r "; break;
case " nel database":  				$messaggio = " finns inte i databasen"; break;
case "Crea l'anno":  				$messaggio = "Skapa &aring;r"; break;
case "Domenica":  				$messaggio = "s&ouml;ndag"; break;
case "Lunedì":  				$messaggio = "m&aring;ndag"; break;
case "Martedì":  				$messaggio = "tisdag"; break;
case "Mercoledì":  				$messaggio = "onsdag"; break;
case "Giovedì":  				$messaggio = "torsdag"; break;
case "Venerdì":  				$messaggio = "fredag"; break;
case "Sabato":	 		 		$messaggio = "l&ouml;rdag"; break;
case "come giorno di inizio/fine locazione":	$messaggio = "som begynnelse-/slutdag f&ouml;r hyran"; break;
case "con periodi":  				$messaggio = "med perioder enligt"; break;
case "settimanali":  				$messaggio = "veckovis"; break;
case "giornalieri":  				$messaggio = "dagligen"; break;
case "e prenotazioni da":  			$messaggio = "och reservationer fr&aring;n"; break;
case "a":  					$messaggio = "till"; break;
case "anno successivo": 			$messaggio = "n&auml;sta &aring;r"; break;
case "anni successivi":  			$messaggio = "&aring;r senare"; break;
case "Importa dall'anno precedente prenotazioni, tariffe (compresi costi aggiuntivi), privilegi degli utenti e regole d'assegnazione.":  $messaggio = "Importera fr&aring;n tidigare &aring;rs reservationer, prislistor (inklusive extrakostnader), anv&auml;ndarprivilegier och &ouml;verl&aring;telseregler."; break;
case "Anno ":  					$messaggio = "&Aring;r "; break;
case " creato":  				$messaggio = " skapad"; break;
case "Non ci sono periodi che riguardano il ":  $messaggio = "Det finns inga perioder f&ouml;r "; break;
case " nel ":  					$messaggio = " "; break;
case ", o il giorno di inizio/fine locazione era differente, sono stati importati solo i dati riguardanti costi aggiuntivi, caparra, nome delle tariffe, privilegi degli utenti e regole di assegnazione 2 e 3":	$messaggio = ", eller begynnelse-/slutdatumet f&ouml;r hyran var annorlunda, endast information om till&auml;gskostnader, depositioner, namn p&aring; prislistor, anv&auml;ndarprivilegier och &ouml;verl&aring;telsereglerna 2 och 3 har importerats"; break;
case "Attenzione</b></font>: i periodi del ":  	$messaggio = "Varning</b></font>: perioderna "; break;
case " finivano dopo quelli del ":  		$messaggio = " slutar efter  "; break;
case " e vi erano":  				$messaggio = " och det finns"; break;
case "prenotazioni che finivano dopo il limite posto al ":	$messaggio = "reservationer som slutar efter gr&auml;nserna som givits f&ouml;r  "; break;
case ", queste prenotazioni non sono state importate":	$messaggio = ", dessa reservationer har inte importerats"; break;
case "Anno già creato": 			$messaggio = "&Aring;ret har redan skapats"; break;
case " Do":  					$messaggio = " S&ouml;"; break;
case " Lu":  					$messaggio = " M&aring;"; break;
case " Ma":  					$messaggio = " Ti"; break;
case " Me":  					$messaggio = " On"; break;
case " Gi":  					$messaggio = " To"; break;
case " Ve":  					$messaggio = " Fr"; break;
case " Sa":  					$messaggio = " L&ouml;"; break;
case "Gen":  					$messaggio = "jan"; break;
case "Feb":  					$messaggio = "feb"; break;
case "Mar":  					$messaggio = "mar"; break;
case "Apr":  					$messaggio = "apr"; break;
case "Mag":  					$messaggio = "maj"; break;
case "Giu":  					$messaggio = "jun"; break;
case "Lug":  					$messaggio = "jul"; break;
case "Ago":  					$messaggio = "aug"; break;
case "Set":  					$messaggio = "sep"; break;
case "Ott":  					$messaggio = "okt"; break;
case "Nov":  					$messaggio = "nov"; break;
case "Dic":  					$messaggio = "dec"; break;
case "Il formato dell'anno richiesto è sbagliato":	$messaggio = "Formatet f&ouml;r det &ouml;nskade &aring;ret &auml;r fel"; break;
case "I mesi erano indicati erroneamente, sono stati inseriti i mesi da Gennaio a Dicembre":	$messaggio = "M&aring;naderna har valts felaktigt, de ska l&auml;ggas in fr&aring;n januari till december"; break;
case "Cognome del cliente":  			$messaggio = "Kund efternamn"; break;
case "Data iniziale":  				$messaggio = "Startdatum"; break;
case "Data finale":  				$messaggio = "Slutdatum"; break;
case "Tariffa completa":  			$messaggio = "Komplett pris"; break;
case "Da pagare":  				$messaggio = "Att betala"; break;
case "Pers":  					$messaggio = "Pers"; break;
case "Registra":  				$messaggio = "Registrera"; break;
case "Entrata":  				$messaggio = "Incheckad"; break;
case "Uscita":  				$messaggio = "Utcheckad"; break;
case "Entrata e pagato":  			$messaggio = "Incheckad och betalad"; break;
case "Uscita e pagato":  			$messaggio = "Utcheckad och betalad"; break;
case "mostra tutte le date":  			$messaggio = "visa alla datum"; break;
case "Utente":  				$messaggio = "Anv&auml;ndare"; break;
case "Esci":  					$messaggio = "Logga ut"; break;
case "Messaggi":  				$messaggio = "Meddelanden"; break;
case "dalla":  					$messaggio = "fr&aring;n"; break;
case "tabella con i periodi e le tariffe":  	$messaggio = "tabellen med perioder och priser"; break;
case "Non ho i permessi di scrittura sulla cartella dati":	$messaggio = "Jag har inte skrivr&auml;ttigheter till dati-mappen"; break;
case "le statistiche":  			$messaggio = "statistiken"; break;
case "inventario e magazzini":  		$messaggio = "inventarier och f&ouml;rvaringsrum"; break;
case "prenotazioni del mese di": 		$messaggio = "reservations in"; break;
case "visualizza": 				$messaggio = "view"; break;
case "tabella con":  				$messaggio = "table with"; break;
case "disponibilità dal":  			$messaggio = "availability from"; break;
case "controlla":  				$messaggio = "check"; break;
case "N&deg;":  				$messaggio = "N&deg;"; break;
case "<span class=\"colred\">Avviso</span>: è consigliabile attendere fino al":	$messaggio = "<span class=\"colred\">Warning</span>: you are advised to wait until"; break;
case "per creare il nuovo anno, nel frattempo si possono aggiungere periodi oltre il":	$messaggio = "before creating the new year, meanwhile you can add periods beyond"; break;
case "anche senza creare un nuovo anno":  	$messaggio = "even without creating a new year"; break;
case "obsoleti":  				$messaggio = "obsolete"; break;
case "Ultimo aggiornamento":  			$messaggio = "Last update"; break;
case "Aggiorna":  				$messaggio = "Update"; break;
case "i documenti salvati":  			$messaggio = "saved documents"; break;
case "Punto vendita":  				$messaggio = "Point of sale"; break;
case "Non ho i permessi per creare nuove tabelle nel database":	$messaggio = "I don't have permissions to create new tables in the database"; break;
case "Benvenuto a HOTELDRUID":  		$messaggio = "Welcome to HOTELDRUID"; break;
case "Scegli la lingua":  			$messaggio = "Choose the language"; break;
case "crea il database":  			$messaggio = "create database"; break;
case "Promemoria":  				$messaggio = "Reminder"; break;
case "Questo utente non ha i privilegi per creare nuovi anni":	$messaggio = "This user has no privileges to create new years"; break;
case "Avviso":  				$messaggio = "Warning"; break;
case "nel database sono ancora disponibili periodi solo per meno di":	$messaggio = "in the database there are still available periods for only less than"; break;
case "mesi":  					$messaggio = "months"; break;
case "OK, ho capito":  				$messaggio = "OK, got it"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
